summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--IvyProbe/TestParseCmdLine.h16
1 files changed, 5 insertions, 11 deletions
diff --git a/IvyProbe/TestParseCmdLine.h b/IvyProbe/TestParseCmdLine.h
index 9a6ae6d..ef8d3ac 100644
--- a/IvyProbe/TestParseCmdLine.h
+++ b/IvyProbe/TestParseCmdLine.h
@@ -1,4 +1,4 @@
// FxParseCmdLine.h: interface for the FxParseCmdLine class.
//
//////////////////////////////////////////////////////////////////////
@@ -9,24 +9,18 @@
#pragma once
#endif // _MSC_VER > 1000
-class FxParseCmdLine : public CCommandLineInfo
+class TestParseCmdLine : public CCommandLineInfo
{
public:
- BOOL m_busstart;
+
BOOL m_start;
- BOOL m_loop;
- UINT m_speed;
- CString m_exoFile;
CString m_busNumber;
virtual void ParseParam( LPCTSTR lpszParam, BOOL bFlag, BOOL bLast );
- FxParseCmdLine();
- virtual ~FxParseCmdLine();
+ TestParseCmdLine();
+ virtual ~TestParseCmdLine();
enum {
- Loop,
BusNumber,
Start,
- ExoFile,
- Speed
}m_shellCommand;
protected:
@@ -1,4 +1,4 @@
-// FxParseCmdLine.h: interface for the FxParseCmdLine class.
+// TestParseCmdLine.h: interface for the TestParseCmdLine class.
//
//////////////////////////////////////////////////////////////////////